@@ -140,18 +140,18 @@ name_usage <- function(key=NULL, name=NULL, data='all', language=NULL,
   return <- match.arg(return, c('meta','data','all'))
   switch(return,
          meta = get_meta_nu(out),
-         data = tibble::as_data_frame(name_usage_parse(out, data)),
+         data = tibble::as_tibble(name_usage_parse(out, data)),
          all = list(meta = get_meta_nu(out),
-                    data = tibble::as_data_frame(name_usage_parse(out, data)))
+                    data = tibble::as_tibble(name_usage_parse(out, data)))
   )
 }
 
 get_meta_nu <- function(x) {
   if (has_meta(x)) {
-    tibble::as_data_frame(data.frame(x[c('offset','limit','endOfRecords')],
+    tibble::as_tibble(data.frame(x[c('offset','limit','endOfRecords')],
                                      stringsAsFactors = FALSE))
   } else {
-    tibble::data_frame()
+    tibble::as_tibble()
   }
 }
 
